==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>La verificación está casi completa, gracias por su paciencia.</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Comprobado por algunos errores.</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ir al escritorio</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Bienvenido, el sistema se actualizó con éxito</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Edición actual:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Ver los registros</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Actualización exitosa</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Su equipo se reiniciará pronto %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Su equipo se apagará pronto %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>El proceso de reinicio automático ha fallado. Intente reiniciar manualmente su dispositivo.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>El proceso de apagado automático ha fallado. Intente apagar manualmente el dispositivo.</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Ocultar registros</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>La actualización falló</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconocido</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>La copia de seguridad falló</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>No se puede realizar la copia de seguridad del sistema. Si continúa con las actualizaciones, no podrá volver al sistema anterior más adelante.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Espacio en disco insuficiente. Limpie el disco e inténtelo de nuevo.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>No se pudo conectar a los servicios de copia de seguridad. Verifique y vuelva a intentarlo.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>No se pudo conectar a los servicios de actualización. Verifique y vuelva a intentarlo.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Error de dependencia</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Error DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Respaldar nuevamente</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Proceder a actualizar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ir al escritorio</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Preparando para actualizar…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>No fuerce un apagado ni apague cuando instale actualizaciones. De lo contrario, su sistema puede dañarse.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.19.tar.xz: BUILD/src/dde-update/translations/dde-update_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>La verificación está casi completa, gracias por su paciencia.</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Comprobado por algunos errores.</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ir al escritorio</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Bienvenido, el sistema se actualizó con éxito</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Edición actual:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Actualización exitosa</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Su equipo se reiniciará pronto %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Su equipo se apagará pronto %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>El proceso de reinicio automático ha fallado. Intente reiniciar manualmente su dispositivo.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>El proceso de apagado automático ha fallado. Intente apagar manualmente el dispositivo.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Ver registros de actualizaciones</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Contraer registros de actualizaciones</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>El registro se exportó al escritorio</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Error al exportar el registro, intente de nuevo</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>La actualización falló</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconocido</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>La copia de seguridad falló</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>No se puede realizar la copia de seguridad del sistema. Si continúa con las actualizaciones, no podrá volver al sistema anterior más adelante.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Espacio en disco insuficiente. Limpie el disco e inténtelo de nuevo.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>No se pudo conectar a los servicios de copia de seguridad. Verifique y vuelva a intentarlo.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>No se pudo conectar a los servicios de actualización. Verifique y vuelva a intentarlo.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Error de dependencia</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Error DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Respaldar nuevamente</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Proceder a actualizar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ir al escritorio</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Preparando para actualizar…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>No fuerce un apagado ni apague cuando instale actualizaciones. De lo contrario, su sistema puede dañarse.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Ver registros de actualizaciones</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Contraer registros de actualizaciones</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>registroactualizaciones</translation>
    </message>
</context>
</TS>
